# Portunus

Detecting lateral movement in multi-tenant environments


# Dependencies

```
docker
docker-compose
faucet
git
pip3
python3
```


# Quick Start

```
pip3 install portunus
portunus
```

In the menu, if it's the first time, choose `Install Dependencies` in addition to `Start Containers`.
